@@ -147,10 +147,6 @@ test_that("test file-backed raster caching", {
       }
       nOT <- Sys.time()
 
-      # xxxx <<- ssss <<- jjjj <<- aaaa <<- bbbb <<- cccc <<- dddd <<- eeee <<- ffff <<- gggg <<- 1
-      #rmFC <<- 1
-      #browser()
-
       for (i in 1:2) {
         assign(paste0("b", i), system.time(
           assign(paste0("a", i), Cache(rasterTobinary, a, cacheRepo = tmpCache, notOlderThan = nOT))
@@ -930,9 +926,9 @@ test_that("test useCache = 'overwrite'", {
 
 test_that("test rm large non-file-backed rasters", {
   ## This is a large object test!
-  skip_on_appveyor()
   skip_on_cran()
-  skip_on_travis()
+
+  skip_on_ci()
 
   if (!is.null(getOption("reproducible.conn", NULL)))
     if (!grepl("SQLite", class(getOption("reproducible.conn", NULL))))
@@ -954,8 +950,9 @@ test_that("test rm large non-file-backed rasters", {
 
 test_that("test cc", {
   skip_on_cran()
-  skip_on_travis()
-  skip_on_appveyor()
+
+  skip_on_ci()
+
   testInitOut <- testInit(ask = FALSE)
   on.exit({
     testOnExit(testInitOut)
@@ -1115,7 +1112,7 @@ test_that("test file link with duplicate Cache", {
   mess2 <- capture_messages({d <- Cache(sample, N, cacheRepo = tmpCache)})
   # Different inputs AND different output -- so no cache recovery and no file link
   expect_true(length(mess2) == 0)
-  out2 <- try(system2("du", tmpCache, stdout = TRUE))
+  out2 <- try(system2("du", tmpCache, stdout = TRUE), silent = TRUE)
   if (!is(out2, "try-error")) {
     fs2 <- as.numeric(gsub("([[:digit:]]*).*", "\\1", out2))
     expect_true(all(fs1 * 1.9 < fs2))
