@@ -6,7 +6,7 @@ test_that("test Copy", {
 
   ras <- raster(extent(0, 10, 0, 10), vals = 1)
   ras <- writeRaster(ras, filename = tmpfile, overwrite = TRUE)
-  ras2 <- Copy(ras, tmpdir)
+  ras2 <- suppressWarningsSpecific(Copy(ras, tmpdir), "NOT UPDATED FOR PROJ >= 6")
   expect_true(all.equal(ras2[], ras[]))
   expect_false(filename(ras2) == filename(ras))
 
