@@ -6,9 +6,12 @@ test_that("preProcess fails if user provides a non .zip/.tar as archive", {
   }, add = TRUE)
   pre <- reproducible::preProcess(
     url = "https://github.com/tati-micheletti/host/raw/master/data/rasterTest.zip",
-    destinationPath = tmpdir)
+    destinationPath = tmpdir
+  )
   testthat::expect_is(object = pre, class = "list")
-  testthat::expect_error(ras <- reproducible::preProcess(archive = pre$targetFilePath))
+  testthat::expect_error({
+    ras <- reproducible::preProcess(archive = pre$targetFilePath)
+  })
 })
 
 test_that("preProcess fails if user provides non-existing file", {
@@ -19,9 +22,12 @@ test_that("preProcess fails if user provides non-existing file", {
   }, add = TRUE)
   pre <- reproducible::preProcess(
     url = "https://github.com/tati-micheletti/host/raw/master/data/rasterTest.zip",
-    destinationPath = tmpdir)
+    destinationPath = tmpdir
+  )
   testthat::expect_is(object = pre, class = "list")
-  testthat::expect_error(ras <- reproducible::preProcess(archive = "fileDoesNotExist.zip"))
+  testthat::expect_error({
+    ras <- reproducible::preProcess(archive = "fileDoesNotExist.zip")
+  })
 })
 
 test_that("preProcess fails if user provides a directory as a targetFile", {
@@ -32,16 +38,22 @@ test_that("preProcess fails if user provides a directory as a targetFile", {
   }, add = TRUE)
   pre <- reproducible::preProcess(
     url = "https://github.com/tati-micheletti/host/raw/master/data/rasterTest.zip",
-    destinationPath = tmpdir)
+    destinationPath = tmpdir
+  )
   testthat::expect_is(object = pre, class = "list")
-  testthat::expect_error(ras <- reproducible::preProcess(targetFile = tmpdir))
+  testthat::expect_error({
+    ras <- reproducible::preProcess(targetFile = tmpdir)
+  })
 })
+
 test_that("preProcess fails if the .rar file is defective", {
   skip_on_cran()
   testInitOut <- testInit("raster", needGoogle = FALSE)
   on.exit({
     testOnExit(testInitOut)
   }, add = TRUE)
-  testthat::expect_error(ras <- preProcess(url = "https://github.com/tati-micheletti/host/blob/master/data/rasterTest.rar",
-                                  destinationPath = tmpdir))
+  testthat::expect_error({
+    ras <- preProcess(url = "https://github.com/tati-micheletti/host/blob/master/data/rasterTest.rar",
+                      destinationPath = tmpdir)
+  })
 })
